Room class

Constructors

Room({String? id, DateTime? updatedAt, String? t, int? msgs, DateTime? ts, DateTime? lm, String? topic, String? rid, List<String>? usernames})
Room.fromMap(Map<String, dynamic>? json)

Properties

hashCode → int
The hash code for this object.
no setteroverride
id ↔ String?
getter/setter pair
lm ↔ DateTime?
getter/setter pair
msgs ↔ int?
getter/setter pair
rid ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
t ↔ String?
getter/setter pair
topic ↔ String?
getter/setter pair
ts ↔ DateTime?
getter/setter pair
updatedAt ↔ DateTime?
getter/setter pair
usernames ↔ List<String>?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override