Notification class

Constructors

Notification({NotificationType? msg, String? collection, String? serverId, List<String>? subs, List<String>? methods, String? id, NotificationFields? fields, NotificationResult? result})
Notification.fromMap(Map<String, dynamic> json)

Properties

collection ↔ String?
getter/setter pair
fields ↔ NotificationFields?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
getter/setter pair
methods ↔ List<String>?
getter/setter pair
msg ↔ NotificationType?
getter/setter pair
result ↔ NotificationResult?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serverId ↔ String?
getter/setter pair
subs ↔ List<String>?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited